package com.ruoyi.inspection.service;

import java.util.List;
import com.ruoyi.inspection.domain.InspectionRecordTable;
import com.ruoyi.inspection.domain.VoReturnInspectionRecordTable;
import com.ruoyi.inspection.domain.VoViewInspectionRecordTable;

/**
 * 巡检记录Service接口
 * 
 * @author ruoyi
 * @date 2024-09-05
 */
public interface IInspectionRecordTableService 
{
    /**
     * 查询巡检记录
     * 
     * @param id 巡检记录主键
     * @return 巡检记录
     */
    public InspectionRecordTable selectInspectionRecordTableById(Long id);

    /**
     * 查询巡检记录列表
     * 
     * @param inspectionRecordTable 巡检记录
     * @return 巡检记录集合
     */
    public List<InspectionRecordTable> selectInspectionRecordTableList(InspectionRecordTable inspectionRecordTable);

    /**
     * 新增巡检记录
     * 
     * @param inspectionRecordTable 巡检记录
     * @return 结果
     */
    public int insertInspectionRecordTable(InspectionRecordTable inspectionRecordTable);

    /**
     * 修改巡检记录
     * 
     * @param inspectionRecordTable 巡检记录
     * @return 结果
     */
    public int updateInspectionRecordTable(InspectionRecordTable inspectionRecordTable);

    /**
     * 批量删除巡检记录
     * 
     * @param ids 需要删除的巡检记录主键集合
     * @return 结果
     */
    public int deleteInspectionRecordTableByIds(Long[] ids);

    /**
     * 删除巡检记录信息
     * 
     * @param id 巡检记录主键
     * @return 结果
     */
    public int deleteInspectionRecordTableById(Long id);

    // 查询巡检记录视图列表
    public VoReturnInspectionRecordTable selectInspectionRecordView(VoViewInspectionRecordTable voViewInspectionRecordTable);

    /**
     * 查询巡检记录列表用于导出数据调整
     *
     * @param inspectionRecordTable 巡检记录
     * @return 巡检记录
     */
    public List<InspectionRecordTable> selectInspectionRecordTableLists(InspectionRecordTable inspectionRecordTable);

}
